@@ -128,14 +128,13 @@ pk.calc.auxc <- function(conc, time, interval=c(0, Inf),
   interval_end <- interval[2]
   # Find the first time point
   if (interval_start < min(data$time)) {
-    rlang::warn(
-      message = sprintf(
+    warn_message <-
+      sprintf(
         "Requesting an AUC range starting (%g) before the first measurement (%g) is not allowed",
         interval_start, min(data$time)
-      ),
-      class = "pknca_warn_auc_before_first"
-    )
-    return(NA)
+      )
+    rlang::warn(message = warn_message, class = "pknca_warn_auc_before_first")
+    return(structure(NA_real_, exclude=warn_message))
   } else if (interval_start > max(data$time)) {
     # Give this as a warning, but allow it to continue
     warning(sprintf("AUC start time (%g) is after the maximum observed time (%g)",
