@@ -1,5 +1,3 @@
-context("Check Conversion")
-
 test_that("check.conversion", {
   good <- LETTERS
   expect_equal(check.conversion(good, as.character), good)
@@ -14,10 +12,8 @@ test_that("check.conversion", {
                as.character(good))
 })
 
-context("Check concentration and time inputs")
-
 test_that("check.conc.time", {
-  ## Check all the invalid cases
+  # Check all the invalid cases
   expect_warning(check.conc.time(conc=-1),
                  regexp="Negative concentrations found")
   expect_warning(check.conc.time(conc=c(NA, -1)),
@@ -25,7 +21,7 @@ test_that("check.conc.time", {
   expect_warning(check.conc.time(conc=c(NA, -1, 1)),
                  regexp="Negative concentrations found")
   expect_warning(check.conc.time(conc=NA),
-                 regexp="All concentration data is missing")
+                 regexp="All concentration data are missing")
   expect_error(check.conc.time(time=NA),
                regexp="Time may not be NA")
   expect_error(check.conc.time(time=c(0, 0)),
@@ -46,8 +42,6 @@ test_that("check.conc.time", {
                regexp="Time data must be numeric and not a factor")
 })
 
-context("Rounding to string values")
-
 test_that("Rounding", {
   expect_error(roundString(1, c(2, 3)),
                regexp="digits must either be a scalar or the same length as x")
@@ -58,7 +52,7 @@ test_that("Rounding", {
   expect_equal(roundString(NaN), "NaN")
   expect_equal(roundString(Inf), "Inf")
   expect_equal(roundString(-Inf), "-Inf")
-  ## Respecting the digits
+  # Respecting the digits
   expect_equal(roundString(0.05, 3), "0.050")
   expect_equal(roundString(123.05, 3), "123.050")
   expect_equal(roundString(c(100, 0.1), 3), c("100.000", "0.100"),
@@ -70,7 +64,7 @@ test_that("Rounding", {
   expect_equal(roundString(c(0.1, NA, NaN, Inf, -Inf), digits=3),
                c("0.100", "NA", "NaN", "Inf", "-Inf"),
                info="Mixed inputs (NA, NaN, Inf or numeric)")
-  ## All zeros
+  # All zeros
   expect_equal(roundString(0, digits=3), "0.000")
   expect_equal(roundString(c(0, NA), digits=3), c("0.000", "NA"))
   # scientific notation
@@ -97,15 +91,19 @@ test_that("Significance", {
   expect_equal(signifString(NaN), "NaN")
   expect_equal(signifString(Inf), "Inf")
   expect_equal(signifString(-Inf), "-Inf")
-  ## Respecting the digits
+  # Respecting the digits
   expect_equal(signifString(0.05, 3), "0.0500")
   expect_equal(signifString(123.05, 3), "123")
   expect_equal(signifString(123456.05, 3), "123000")
   expect_warning(signifString(123456.05, 3, si_range=6),
                 regexp="The si_range argument is deprecated, please use sci_range")
-  expect_equal(signifString(123456.05, 3, sci_range=6),
-               expect_warning(signifString(123456.05, 3, si_range=6)),
-               info="si_range and sci_range arguments are treated equally.")
+  expect_warning(
+    expect_equal(
+      signifString(123456.05, 3, sci_range=6),
+      signifString(123456.05, 3, si_range=6),
+      info="si_range and sci_range arguments are treated equally."
+    )
+  )
   expect_equal(signifString(123456.05, 3, sci_range=6), "123000")
   expect_equal(signifString(123456.05, 3, sci_range=5), "1.23e5")
   expect_equal(signifString(-123000.05, 3, sci_range=5), "-1.23e5")
@@ -114,20 +112,20 @@ test_that("Significance", {
   expect_equal(signifString(999999, 7, sci_range=6), "999999.0",
                info="Rounding around the edge of the sci_range works correctly (going staying the same)")
   expect_equal(signifString(-.05, 3), "-0.0500")
-  ## Exact orders of magnitude work on both sides of 0
+  # Exact orders of magnitude work on both sides of 0
   expect_equal(signifString(0.01, 3), "0.0100")
   expect_equal(signifString(1, 3), "1.00")
   expect_equal(signifString(100, 3), "100")
-  ## Vectors work with different orders of magnitude work
+  # Vectors work with different orders of magnitude work
   expect_equal(signifString(c(100, 0.1), 3), c("100", "0.100"))
-  ## Rounding to a higher number of significant digits works correctly
+  # Rounding to a higher number of significant digits works correctly
   expect_equal(signifString(0.9999999, 3), "1.00")
-  ## Mixed inputs (NA, NaN, Inf or numeric)
+  # Mixed inputs (NA, NaN, Inf or numeric)
   expect_equal(signifString(NA), "NA")
   expect_equal(signifString(c(0.1, NA), digits=3), c("0.100", "NA"))
   expect_equal(signifString(c(0.1, NA, NaN, Inf, -Inf), digits=3),
                c("0.100", "NA", "NaN", "Inf", "-Inf"))
-  ## All zeros
+  # All zeros
   expect_equal(signifString(0, digits=3), "0.000")
   expect_equal(signifString(c(0, NA), digits=3), c("0.000", "NA"))
 
@@ -139,28 +137,32 @@ test_that("Significance", {
                info="Different numbers of digits for rounding work with signifString")
   
   # Data Frames
-  expect_equal(signifString(data.frame(A=c(0, 1.111111),
-                                       B=factor(LETTERS[1:2]),
-                                       C=LETTERS[1:2],
-                                       stringsAsFactors=FALSE),
-                            digits=3),
-               data.frame(A=c("0.000", "1.11"),
-                          B=factor(LETTERS[1:2]),
-                          C=LETTERS[1:2],
-                          stringsAsFactors=FALSE),
-               check.attributes=FALSE,
-               info="Data frame significance is calculated correctly")
-  expect_equal(signifString(data.frame(A=c(0, 1.111111),
-                                       B=factor(LETTERS[1:2]),
-                                       C=LETTERS[1:2],
-                                       stringsAsFactors=FALSE),
-                            digits=4),
-               data.frame(A=c("0.0000", "1.111"),
-                          B=factor(LETTERS[1:2]),
-                          C=LETTERS[1:2],
-                          stringsAsFactors=FALSE),
-               check.attributes=FALSE,
-               info="Data frame digits are respected")
+  expect_equal(
+    signifString(data.frame(A=c(0, 1.111111),
+                            B=factor(LETTERS[1:2]),
+                            C=LETTERS[1:2],
+                            stringsAsFactors=FALSE),
+                 digits=3),
+    data.frame(A=c("0.000", "1.11"),
+               B=factor(LETTERS[1:2]),
+               C=LETTERS[1:2],
+               stringsAsFactors=FALSE),
+    ignore_attr=TRUE,
+    info="Data frame significance is calculated correctly"
+  )
+  expect_equal(
+    signifString(data.frame(A=c(0, 1.111111),
+                            B=factor(LETTERS[1:2]),
+                            C=LETTERS[1:2],
+                            stringsAsFactors=FALSE),
+                 digits=4),
+    data.frame(A=c("0.0000", "1.111"),
+               B=factor(LETTERS[1:2]),
+               C=LETTERS[1:2],
+               stringsAsFactors=FALSE),
+    ignore_attr=TRUE,
+    info="Data frame digits are respected"
+  )
 })
 
 test_that("signifString stops when bad arguments are passed", {
@@ -177,7 +179,7 @@ test_that("max_na and min_na", {
   expect_equal(max_zero_len(1, NA), max(1, NA))
   expect_equal(max_zero_len(1, NA, na.rm=TRUE), max(1, NA, na.rm=TRUE))
   expect_equal(
-    max_zero_len(c(), na.rm=TRUE),
+    max_zero_len(numeric(), na.rm=TRUE),
     NA
   )
   expect_equal(
