@@ -1,7 +1,98 @@
-context("Interpolation and extrapolation of concentration")
+# expected errors ####
 
-test_that("extrapolate.conc", {
-  # Confirm that the ecxtrap.method must be AUCinf, AUClast, AUCall
+## interpolate.conc expected errors ####
+
+test_that("interpolate.conc expected errors", {
+  # Ensure that it is an error to extrapolate past the last point.
+  expect_error(
+    interpolate.conc(
+      conc=c(0, 1, 0.5, 1, 0),
+      time=0:4,
+      time.out=5,
+      interp.method="lin up/log down"
+    ),
+    regexp="`interpolate.conc()` does not extrapolate, use `interp.extrap.conc()`",
+    fixed=TRUE
+  )
+  # Change documentation when this is not true
+  expect_error(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=0:1
+    ),
+    regexp="Assertion on 'time.out' failed: Must have length 1."
+  )
+  
+  expect_error(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=0.5,
+      interp.method="this doesn't work"
+    ),
+    regexp=tryCatch(expr={
+      match.arg("foo", choices=c("lin up/log down", "linear"))
+    },
+    error=function(e) e)$message,
+    fixed=TRUE,
+    info="Confirm that invalid interpolation methods are an error."
+  )
+  
+  expect_error(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=0.5,
+      conc.origin=1:2
+    ),
+    regexp="Assertion on 'conc.origin' failed: Must have length 1."
+  )
+  expect_error(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=0.5,
+      conc.origin="A"
+    ),
+    regexp="Assertion on 'conc.origin' failed: Must be of type 'number', not 'character'."
+  )
+  expect_error(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=0.5,
+      conc.origin=factor("A")
+    ),
+    regexp="Assertion on 'conc.origin' failed: Must be of type 'number', not 'factor'."
+  )
+  
+  expect_error(
+    interpolate.conc(
+      conc=c(NA, 1),
+      time=c(0, 1),
+      time.out=0.5,
+      check=FALSE
+    ),
+    regexp="Contains missing values"
+  )
+
+  # When tlast is before the end of the data, do not extrapolate  
+  expect_error(
+    interpolate.conc(
+      conc=c(1, 2, 0),
+      time=0:2,
+      time.out=1.5
+    ),
+    regexp="`interpolate.conc()` can only works through Tlast, please use `interp.extrap.conc()` to combine both interpolation and extrapolation.",
+    fixed=TRUE
+  )
+})
+
+## extrapolate.conc expected errors ####
+
+test_that("extrapolate.conc expected errors", {
+  # Confirm that the extrap.method must be AUCinf, AUClast, AUCall
   expect_error(
     extrapolate.conc(
       conc=1,
@@ -11,7 +102,7 @@ test_that("extrapolate.conc", {
     ),
     regexp="extrap.method must be one of 'AUCinf', 'AUClast', or 'AUCall'"
   )
-
+  
   # Confirm that time.out may only be a scalar
   expect_error(
     extrapolate.conc(
@@ -22,19 +113,6 @@ test_that("extrapolate.conc", {
     ),
     regexp="Only one time.out value may be estimated at once."
   )
-
-  # Ensure that if Clast is NA that the extrapolated concentration is NA.
-  expect_warning(
-    v1 <-
-      extrapolate.conc(
-        conc=NA,
-        time=1,
-        time.out=2,
-        extrap.method="AUCinf"
-      )
-  )
-  expect_equal(v1, NA)
-
   # Confirm that it is an error to extrapolate at or before Tlast
   expect_error(
     extrapolate.conc(
@@ -54,6 +132,404 @@ test_that("extrapolate.conc", {
     ),
     regexp="extrapolate.conc can only work beyond Tlast, please use interp.extrap.conc to combine both interpolation and extrapolation."
   )
+})
+
+## interp.extrap.conc expected errors ####
+
+test_that("interp.extrap.conc expected errors", {
+  # Check inputs
+  expect_error(
+    interp.extrap.conc(
+      conc=c(0, 1, 0.5, 1, 0),
+      time=0:4,
+      time.out=numeric(),
+      interp.method="lin up/log down"
+    ),
+    regexp="time.out must be a vector with at least one element"
+  )
+})
+
+## interp.extrap.conc.dose expected errors ####
+
+test_that("interp.extrap.conc.dose expected errors", {
+  # Check inputs
+  expect_error(
+    interp.extrap.conc.dose(
+      conc=c(0, 1, 2, 1, 0.5, 0.25),
+      time=c(-1, 1:5),
+      time.dose=0,
+      route.dose="foo",
+      duration.dose=NA,
+      time.out=c(-1, -0.1, 0, 0.1, 7),
+      out.after=FALSE
+    ),
+    regexp="route.dose must be either 'extravascular' or 'intravascular'",
+    info="Route must be valid"
+  )
+  expect_error(
+    interp.extrap.conc.dose(
+      conc=c(0, 1, 2, 1, 0.5, 0.25),
+      time=c(-1, 1:5),
+      time.dose=0,
+      route.dose=factor("foo"),
+      duration.dose=NA,
+      time.out=c(-1, -0.1, 0, 0.1, 7),
+      out.after=FALSE
+    ),
+    regexp="route.dose must be either 'extravascular' or 'intravascular'",
+    info="Route must be valid (as a factor)"
+  )
+  expect_error(
+    interp.extrap.conc.dose(
+      conc=c(0, 1, 2, 1, 0.5, 0.25),
+      time=c(-1, 1:5),
+      time.dose=0,
+      route.dose=c("extravascular", "extravascular"),
+      duration.dose=NA,
+      time.out=c(-1, -0.1, 0, 0.1, 7),
+      out.after=FALSE
+    ),
+    regexp="route.dose must either be a scalar or the same length as time.dose",
+    info="Route must have the correct length"
+  )
+  expect_error(
+    interp.extrap.conc.dose(
+      conc=c(0, 1, 2, 1, 0.5, 0.25),
+      time=c(-1, 1:5),
+      time.dose=0,
+      route.dose="extravascular",
+      duration.dose="A",
+      time.out=c(-1, -0.1, 0, 0.1, 7),
+      out.after=FALSE
+    ),
+    regexp="duration.dose must be NA or a number.",
+    info="duration.dose must be NA or a number (character)."
+  )
+  expect_error(
+    interp.extrap.conc.dose(
+      conc=c(0, 1, 2, 1, 0.5, 0.25),
+      time=c(-1, 1:5),
+      time.dose=0,
+      route.dose="extravascular",
+      duration.dose=factor("A"),
+      time.out=c(-1, -0.1, 0, 0.1, 7),
+      out.after=FALSE
+    ),
+    regexp="duration.dose must be NA or a number.",
+    info="duration.dose must be NA or a number (factor)."
+  )
+  expect_error(
+    interp.extrap.conc.dose(
+      conc=c(0, 1, 2, 1, 0.5, 0.25),
+      time=c(-1, 1:5),
+      time.dose=0,
+      route.dose="extravascular",
+      duration.dose=c(1, NA),
+      time.out=c(-1, -0.1, 0, 0.1, 7),
+      out.after=FALSE
+    ),
+    regexp="duration.dose must either be a scalar or the same length as time.dose",
+    info="duration.dose must match the length of time.dose or be a scalar."
+  )
+})
+
+# interpolate.conc ####
+
+test_that("interpolate.conc", {
+  # Confirm that interpolating between all zeros results in zero
+  interp_method <- c("linear", "lin up/log down")
+  for (n in interp_method) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 0),
+        time=0:1,
+        time.out=0,
+        interp.method=n
+      ),
+      0,
+      info=paste("all zero", n)
+    )
+  }
+  
+  # Confirm that interpolating to a given point results in the point itself
+  interpolations <-
+    list(
+      linear=0,
+      "lin up/log down"=0
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1),
+        time=0:1,
+        time.out=0,
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  
+  interpolations <-
+    list(
+      linear=1,
+      "lin up/log down"=1
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1),
+        time=0:1,
+        time.out=1,
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  
+  # Confirm that interpolating to a given point when that point is NA gives a
+  # interpolates as expected.
+  interpolations <-
+    list(
+      linear=1,
+      "lin up/log down"=1
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1, NA, 1),
+        time=0:3,
+        time.out=2,
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  
+  # Slightly less trivial tests
+  interpolations <-
+    list(
+      linear=0.5,
+      "lin up/log down"=0.5
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1, 0),
+        time=0:2,
+        time.out=0.5,
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  
+  interpolations <-
+    list(
+      linear=1.75,
+      "lin up/log down"=2^0.75
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 2, 1),
+        time=0:2,
+        time.out=1.25,
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  # Relative time is the only thing that matters.  Negative time
+  # values are fine.
+  interpolations <-
+    list(
+      linear=1.75,
+      "lin up/log down"=2^0.75
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 2, 1),
+        time=seq(-10, -8, by=1),
+        time.out=-8.75,
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  # Ensure that linear-up/log down interpolation works linearly for the "up"
+  # even if it is after a down.
+  interpolations <-
+    list(
+      linear=0.25,
+      "lin up/log down"=0.25
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1, 0, 1, 0),
+        time=0:4,
+        time.out=2.25,
+        conc.blq="keep",
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  
+  # Ensure that interpolation with linear works with a BLQ in the middle: going
+  # down and up from that BLQ
+  interpolations <-
+    list(
+      linear=0.5,
+      "lin up/log down"=0.5
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1, 0, 1, 0),
+        time=0:4,
+        time.out=1.5,
+        conc.blq="keep",
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  
+  interpolations <-
+    list(
+      linear=0.5,
+      "lin up/log down"=0.5
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1, 0, 1, 0),
+        time=0:4,
+        time.out=2.5,
+        conc.blq="keep",
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  
+  # Ensure that conc.blq is appropriately observed
+  interpolations <-
+    list(
+      linear=1,
+      "lin up/log down"=1
+    )
+  for (n in names(interpolations)) {
+    expect_equal(
+      interpolate.conc(
+        conc=c(0, 1, 0, 1, 0),
+        time=0:4,
+        time.out=2.25,
+        conc.blq="drop",
+        interp.method=n
+      ),
+      interpolations[[n]],
+      info=n
+    )
+  }
+  # Ensure that the "log down" part works, too.
+  expect_equal(
+    interpolate.conc(
+      conc=c(0, 1, 0.5, 1, 0),
+      time=0:4,
+      time.out=1.5,
+      interp.method="lin up/log down"),
+    exp(mean(log(c(1, 0.5))))
+  )
+  
+  # Confirm that extrapolating before the first time uses conc.origin
+  expect_equal(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=-1),
+    0,
+    info="conc.origin defaults to zero"
+  )
+  expect_equal(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=-1,
+      conc.origin=NA),
+    NA,
+    info="conc.origin is honored as NA"
+  )
+  expect_equal(
+    interpolate.conc(
+      conc=0:1,
+      time=0:1,
+      time.out=-1,
+      conc.origin=5
+    ),
+    5,
+    info="conc.origin is honored as a number"
+  )
+  
+  # expect_equal(
+  #   interpolate.conc(
+  #     conc=c(NA, 1, 2),
+  #     time=c(0, 1, 2),
+  #     time.out=1.5,
+  #     check=FALSE
+  #   ),
+  #   1.5,
+  #   info="Skipping the checks with an NA, but not bounding the interpolation gives the expected value."
+  # )
+  
+  # by default, zeros in the middle are omitted
+  expect_equal(
+    interpolate.conc(
+      conc=c(0, 1, 2, 0, 1, 0),
+      time=0:5,
+      time.out=3,
+      conc.blq=NULL
+    ),
+    exp(mean(log(c(2, 1))))
+  )
+  # Zeros in the middle are accurately interpolated
+  expect_equal(
+    interpolate.conc(
+      conc=c(0, 1, 2, 0, 1, 0),
+      time=0:5,
+      time.out=2.5,
+      conc.blq=0
+    ),
+    1
+  )
+})
+
+# extrapolate.conc ####
+
+test_that("extrapolate.conc", {
+  # Ensure that if Clast is NA that the extrapolated concentration is NA.
+  expect_warning(
+    v1 <-
+      extrapolate.conc(
+        conc=NA,
+        time=1,
+        time.out=2,
+        extrap.method="AUCinf"
+      ),
+    regexp="All concentration data are missing"
+  )
+  expect_equal(v1, NA)
 
   # Extrapolating AUClast is always 0
   expect_equal(
@@ -148,17 +624,18 @@ test_that("extrapolate.conc", {
   )
 
   # Extrapolating with all NA is NA.
-  expect_equal(
-    expect_warning(
+  expect_warning(
+    expect_equal(
       extrapolate.conc(
         conc=rep(NA, 3),
         time=1:3,
         time.out=2.5,
         lambda.z=NA,
         extrap.method="AUCinf"
-      )
+      ),
+      NA
     ),
-    NA
+    class = "pknca_conc_all_missing"
   )
 
   # Ensure that extrapolation beyond the last point works if the last point is 0
@@ -222,333 +699,20 @@ test_that("extrapolate.conc", {
   }
 })
 
-test_that("interpolate.conc", {
-  # Confirm that interpolating to a given point results in the point itself
-  interpolations <-
-    list(
-      linear=0,
-      "lin up/log down"=0
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1),
-        time=0:1,
-        time.out=0,
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-
-  interpolations <-
-    list(
-      linear=1,
-      "lin up/log down"=1
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1),
-        time=0:1,
-        time.out=1,
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-
-  # Confirm that interpolating to a given point when that point is NA gives a
-  # interpolates as expected.
-  interpolations <-
-    list(
-      linear=1,
-      "lin up/log down"=1
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1, NA, 1),
-        time=0:3,
-        time.out=2,
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-
-  # Slightly less trivial tests
-  interpolations <-
-    list(
-      linear=0.5,
-      "lin up/log down"=0.5
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1, 0),
-        time=0:2,
-        time.out=0.5,
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-
-  interpolations <-
-    list(
-      linear=1.75,
-      "lin up/log down"=2^0.75
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 2, 1),
-        time=0:2,
-        time.out=1.25,
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-  # Relative time is the only thing that matters.  Negative time
-  # values are fine.
-  interpolations <-
-    list(
-      linear=1.75,
-      "lin up/log down"=2^0.75
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 2, 1),
-        time=seq(-10, -8, by=1),
-        time.out=-8.75,
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-  # Ensure that linear-up/log down interpolation works linearly for the "up"
-  # even if it is after a down.
-  interpolations <-
-    list(
-      linear=0.25,
-      "lin up/log down"=0.25
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1, 0, 1, 0),
-        time=0:4,
-        time.out=2.25,
-        conc.blq="keep",
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-
-  # Ensure that interpolation with linear works with a BLQ in the middle: going
-  # down and up from that BLQ
-  interpolations <-
-    list(
-      linear=0.5,
-      "lin up/log down"=0.5
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1, 0, 1, 0),
-        time=0:4,
-        time.out=1.5,
-        conc.blq="keep",
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-
-  interpolations <-
-    list(
-      linear=0.5,
-      "lin up/log down"=0.5
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1, 0, 1, 0),
-        time=0:4,
-        time.out=2.5,
-        conc.blq="keep",
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-
-  # Ensure that conc.blq is appropriately observed
-  interpolations <-
-    list(
-      linear=1,
-      "lin up/log down"=1
-    )
-  for (n in names(interpolations)) {
-    expect_equal(
-      interpolate.conc(
-        conc=c(0, 1, 0, 1, 0),
-        time=0:4,
-        time.out=2.25,
-        conc.blq="drop",
-        interp.method=n
-      ),
-      interpolations[[n]],
-      info=n
-    )
-  }
-  # Ensure that the "log down" part works, too.
-  expect_equal(
-    interpolate.conc(
-      conc=c(0, 1, 0.5, 1, 0),
-      time=0:4,
-      time.out=1.5,
-      interp.method="lin up/log down"),
-    exp(mean(log(c(1, 0.5))))
-  )
-
-  # Ensure that it is an error to extrapolate past the last point.
-  expect_error(
-    interpolate.conc(
-      conc=c(0, 1, 0.5, 1, 0),
-      time=0:4,
-      time.out=5,
-      interp.method="lin up/log down"
-    ),
-    regexp="`interpolate.conc()` can only works through Tlast, please use `interp.extrap.conc()` to combine both interpolation and extrapolation.",
-    fixed=TRUE
-  )
-
-  # Confirm that extrapolating before the first time uses conc.origin
-  expect_equal(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=-1),
-    0,
-    info="conc.origin defaults to zero"
-  )
-  expect_equal(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=-1,
-      conc.origin=NA),
-    NA,
-    info="conc.origin is honored as NA"
-  )
-  expect_equal(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=-1,
-      conc.origin=5
-    ),
-    5,
-    info="conc.origin is honored as a number"
-  )
-  
-  expect_equal(
-    interpolate.conc(
-      conc=c(NA, 1),
-      time=c(0, 1),
-      time.out=0.5,
-      check=FALSE
-    ),
-    NA_real_,
-    info="Skipping the checks with an NA bounding the interpolation gives NA"
-  )
-  
-  expect_equal(
-    interpolate.conc(
-      conc=c(NA, 1, 2),
-      time=c(0, 1, 2),
-      time.out=1.5,
-      check=FALSE
-    ),
-    1.5,
-    info="Skipping the checks with an NA, but not bounding the interpolation gives the expected value."
-  )
-
-  # Confirm errors that should happen ####
-
-  # Change documentation when this is not true
-  expect_error(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=0:1
-    ),
-    regexp="Can only interpolate for one time point per function call",
-    info="Confirm that more than one time.out requested is an error"
-  )
-
-  expect_error(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=0.5,
-      interp.method="this doesn't work"
-    ),
-    regexp=tryCatch(expr={
-      match.arg("foo", choices=c("lin up/log down", "linear"))
-    },
-    error=function(e) e)$message,
-    fixed=TRUE,
-    info="Confirm that invalid interpolation methods are an error."
-  )
-
-  expect_error(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=0.5,
-      conc.origin=1:2
-    ),
-    regexp="conc.origin must be a scalar",
-    info="conc.origin must be a scalar"
-  )
-  expect_error(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=0.5,
-      conc.origin="A"
-    ),
-    regexp="conc.origin must be NA or a number \\(and not a factor\\)",
-    info="conc.origin must be a number and not a factor (character)"
-  )
-  expect_error(
-    interpolate.conc(
-      conc=0:1,
-      time=0:1,
-      time.out=0.5,
-      conc.origin=factor("A")
-    ),
-    regexp="conc.origin must be NA or a number \\(and not a factor\\)",
-    info="conc.origin must be a number and not a factor (factor)"
-  )
-})
+# interp.extrap.conc ####
 
 test_that("interp.extrap.conc", {
+  # All zeros always interpolates to all zeros
+  expect_equal(
+    interp.extrap.conc(
+      conc=c(0, 0, 0),
+      time=0:2,
+      time.out=c(0, 0.5, 2.5),
+      interp.method="lin up/log down"
+    ),
+    rep(0, 3)
+  )
+  
   # Ensure that data checking works correctly
   expect_equal(
     interp.extrap.conc(
@@ -561,16 +725,16 @@ test_that("interp.extrap.conc", {
   )
 
   # Ensure that NA for time.out results in NA output
-  expect_equal(
-    expect_warning(
+  expect_warning(
+    expect_equal(
       interp.extrap.conc(
         conc=c(0, 1, 0.5, 1, 0),
         time=0:4,
         time.out=c(1.5, NA),
         interp.method="lin up/log down"
-      )
-    ),
-    c(exp(mean(log(c(1, 0.5)))), NA)
+      ),
+      c(exp(mean(log(c(1, 0.5)))), NA)
+    )
   )
 
   # Ensure a warning with NA for time.out
@@ -583,19 +747,10 @@ test_that("interp.extrap.conc", {
     ),
     regexp="An interpolation/extrapolation time is NA"
   )
-
-  # Check inputs
-  expect_error(
-    interp.extrap.conc(
-      conc=c(0, 1, 0.5, 1, 0),
-      time=0:4,
-      time.out=c(),
-      interp.method="lin up/log down"
-    ),
-    regexp="time.out must be a vector with at least one element"
-  )
 })
 
+# interp.extrap.conc.dose ####
+
 test_that("interp.extrap.conc.dose handles all eventualities", {
   event_choices <- unlist(event_choices_interp.extrap.conc.dose, use.names=FALSE)
   eventualities <-
@@ -631,73 +786,6 @@ test_that("interp.extrap.conc.dose handles all eventualities", {
 })
 
 test_that("interp.extrap.conc.dose", {
-  # Check inputs
-  expect_error(
-    interp.extrap.conc.dose(
-      conc=c(0, 1, 2, 1, 0.5, 0.25),
-      time=c(-1, 1:5),
-      time.dose=0,
-      route.dose="foo",
-      duration.dose=NA,
-      time.out=c(-1, -0.1, 0, 0.1, 7),
-      out.after=FALSE
-    ),
-    regexp="route.dose must be either 'extravascular' or 'intravascular'",
-    info="Route must be valid"
-  )
-  expect_error(
-    interp.extrap.conc.dose(
-      conc=c(0, 1, 2, 1, 0.5, 0.25),
-      time=c(-1, 1:5),
-      time.dose=0,
-      route.dose=c("extravascular", "extravascular"),
-      duration.dose=NA,
-      time.out=c(-1, -0.1, 0, 0.1, 7),
-      out.after=FALSE
-    ),
-    regexp="route.dose must either be a scalar or the same length as time.dose",
-    info="Route must have the correct length"
-  )
-  expect_error(
-    interp.extrap.conc.dose(
-      conc=c(0, 1, 2, 1, 0.5, 0.25),
-      time=c(-1, 1:5),
-      time.dose=0,
-      route.dose="extravascular",
-      duration.dose="A",
-      time.out=c(-1, -0.1, 0, 0.1, 7),
-      out.after=FALSE
-    ),
-    regexp="duration.dose must be NA or a number.",
-    info="duration.dose must be NA or a number (character)."
-  )
-  expect_error(
-    interp.extrap.conc.dose(
-      conc=c(0, 1, 2, 1, 0.5, 0.25),
-      time=c(-1, 1:5),
-      time.dose=0,
-      route.dose="extravascular",
-      duration.dose=factor("A"),
-      time.out=c(-1, -0.1, 0, 0.1, 7),
-      out.after=FALSE
-    ),
-    regexp="duration.dose must be NA or a number.",
-    info="duration.dose must be NA or a number (factor)."
-  )
-  expect_error(
-    interp.extrap.conc.dose(
-      conc=c(0, 1, 2, 1, 0.5, 0.25),
-      time=c(-1, 1:5),
-      time.dose=0,
-      route.dose="extravascular",
-      duration.dose=c(1, NA),
-      time.out=c(-1, -0.1, 0, 0.1, 7),
-      out.after=FALSE
-    ),
-    regexp="duration.dose must either be a scalar or the same length as time.dose",
-    info="duration.dose must match the length of time.dose or be a scalar."
-  )
-
   expect_equal(
     interp.extrap.conc.dose(
       conc=c(0, 1, 2, 1, 0.5, 0.25),
@@ -780,21 +868,21 @@ test_that("interp.extrap.conc.dose", {
     info="Extrapolation to a dose then interpolation between the dose and the next time works."
   )
 
-  expect_equal(
-    expect_warning(
-        interp.extrap.conc.dose(
-          conc=c(0, 1, 2, 1, 0.5, 0.25),
-          time=c(-1, 1:5),
-          time.dose=c(0, 0.1),
-          time.out=0.2
-        ),
-        regexp="Cannot interpolate between two doses or after a dose without a concentration after the first dose.",
-        fixed=TRUE,
-        info="Two doses in a row generates a warning"
-    ),
-    structure(NA_real_, Method="Dose before, concentration after without a dose"),
-    info="Extrapolation to a dose then interpolation between the dose and the next time gives NA when the dose is NA."
-  )
+  # expect_equal(
+  #   expect_warning(
+  #       interp.extrap.conc.dose(
+  #         conc=c(0, 1, 2, 1, 0.5, 0.25),
+  #         time=c(-1, 1:5),
+  #         time.dose=c(0, 0.1),
+  #         time.out=0.2
+  #       ),
+  #       regexp="Cannot interpolate between two doses or after a dose without a concentration after the first dose.",
+  #       fixed=TRUE,
+  #       info="Two doses in a row generates a warning"
+  #   ),
+  #   structure(NA_real_, Method="Dose before, concentration after without a dose"),
+  #   info="Extrapolation to a dose then interpolation between the dose and the next time gives NA when the dose is NA."
+  # )
 
   expect_equal(
     interp.extrap.conc.dose(
@@ -949,3 +1037,4 @@ test_that("interp.extrap.conc.dose", {
     info="Outputs are in the same order as inputs (reverse sorted time.out)"
   )
 })
+
